---------------------------------------------------------------------------
-- This VHDL file was developed by Daniel Llamocca (2013).  It may be
-- freely copied and/or distributed at no cost.  Any persons using this
-- file for any purpose do so at their own risk, and are responsible for
-- the results of such use.  Daniel Llamocca does not guarantee that
-- this file is complete, correct, or fit for any particular purpose.
-- NO WARRANTY OF ANY KIND IS EXPRESSED OR IMPLIED.  This notice must
-- accompany any copy of this file.
--------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
 
-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--USE ieee.numeric_std.ALL;
 
ENTITY tb_my_pashiftreg IS
END tb_my_pashiftreg;
 
ARCHITECTURE behavior OF tb_my_pashiftreg IS 
 
    -- Component Declaration for the Unit Under Test (UUT)
 
    COMPONENT my_pashiftreg
    PORT(
         clock : IN  std_logic;
         resetn : IN  std_logic;
         din : IN  std_logic;
         E : IN  std_logic;
         s_l : IN  std_logic;
         D : IN  std_logic_vector(3 downto 0);
         Q : OUT  std_logic_vector(3 downto 0);
         shiftout : OUT  std_logic
        );
    END COMPONENT;
    

   --Inputs
   signal clock : std_logic := '0';
   signal resetn : std_logic := '0';
   signal din : std_logic := '0';
   signal E : std_logic := '0';
   signal s_l : std_logic := '0';
   signal D : std_logic_vector(3 downto 0) := (others => '0');

 	--Outputs
   signal Q : std_logic_vector(3 downto 0);
   signal shiftout : std_logic;

   -- Clock period definitions
   constant T : time := 20 ns;
 
BEGIN
 
	-- Instantiate the Unit Under Test (UUT)
   uut: my_pashiftreg PORT MAP (
          clock => clock,
          resetn => resetn,
          din => din,
          E => E,
          s_l => s_l,
          D => D,
          Q => Q,
          shiftout => shiftout
        );

   -- Clock process definitions
   clock_process :process
   begin
		clock <= '0'; wait for T/2;
		clock <= '1'; wait for T/2;
   end process;
 

   -- Stimulus process
   stim_proc: process
   begin		
      -- hold reset state for 100 ns.
		resetn <= '0'; wait for 100 ns;
		resetn <= '0'; wait for T*2;
		resetn <= '1';
		D <= "0000"; din <= '1'; E <= '1'; s_l <= '0'; wait for T*2;
		D <= "1101"; din <= '0'; E <= '1'; s_l <= '0'; wait for T;
		D <= "1101"; din <= '1'; E <= '1'; s_l <= '0'; wait for T*2;
		D <= "1101"; din <= '1'; E <= '0'; s_l <= '0'; wait for T;
		
		E <= '1';
		D <= "1101"; din <= '0'; s_l <= '0'; wait for T;
		D <= "1101"; din <= '1'; s_l <= '1'; wait for T;
		D <= "1001"; din <= '0'; s_l <= '0'; wait for T;
		D <= "1100";
		din <= '0'; s_l <= '1'; wait for T;
		din <= '0'; s_l <= '0'; wait for T*2;		
		din <= '1'; s_l <= '0'; wait for T;
		din <= '0'; s_l <= '1'; wait for T;
		din <= '0'; s_l <= '0'; wait for T*2;		
		wait;
      
   end process;

END;
